""" The *definition* of a tool bar. """

# Enthought library imports.
from traits.api import Instance, List, Str

# Local imports.
from .group import Group
from .location import Location
from ..._compat import STRING_BASE_CLASS


# fixme: Remove duplication (in menu.py too!)
class CGroup(Instance):
    """ A trait type for a 'Group' or anything that can be cast to a 'Group'.

    Currently, the only cast allowed is from string -> Group using the
    string as the group's ID.

    """

    ###########################################################################
    # 'object' interface.
    ###########################################################################

    def __init__(self, **kw):
        """ Constructor. """

        super(CGroup, self).__init__(klass=Group, **kw)

        return

    ###########################################################################
    # 'TraitType' interface.
    ###########################################################################

    def validate(self, object, name, value):
        """ Validate a value. """

        if isinstance(value, STRING_BASE_CLASS):
            value = Group(id=value)

        return super(CGroup, self).validate(object, name, value)


class ToolBar(Location):
    """ The *definition* of a menu in a menu bar or menu. """

    # The tool bars's unique identifier (unique within the multi-toolbar
    # that the tool bar is to be added to).
    id = Str

    # The tool bar name (appears when the tool bar is 'undocked').
    name = Str

    # The groups in the tool bar.
    groups = List(CGroup)

    # The optional name of a class that implements the tool bar. The class must
    # support the **pyface.action.ToolBarManager** protocol.
    class_name = Str

    ###########################################################################
    # 'object' interface
    ###########################################################################

    def __str__(self):
        """ Return the 'informal' string representation of the object. """

        return 'ToolBar(%s)' % self.name

    __repr__ = __str__

    ###########################################################################
    # 'Location' interface
    ###########################################################################

    def _path_default(self):
        """ Trait initializer. """

        return 'ToolBar'

    ###########################################################################
    # 'ToolBar' interface
    ###########################################################################

    def _id_default(self):
        """ Trait initializer. """

        return self.name

#### EOF ######################################################################



""" The main preferences page for the workbench. """


# Enthought library imports.
from apptools.preferences.ui.api import PreferencesPage
from traits.api import Bool
from traitsui.api import View


class WorkbenchPreferencesPage(PreferencesPage):
    """ The main preferences page for the workbench. """

    #### 'PreferencesPage' interface ##########################################

    # The page's category (e.g. 'General/Appearance'). The empty string means
    # that this is a top-level page.
    category = ''

    # The page's help identifier (optional). If a help Id *is* provided then
    # there will be a 'Help' button shown on the preference page.
    help_id = ''

    # The page name (this is what is shown in the preferences dialog.
    name = 'General'

    # The path to the preferences node that contains the preferences.
    preferences_path = 'envisage.ui.workbench'

    #### Preferences ##########################################################

    # Should the user be prompted before exiting the workbench?
    prompt_on_exit = Bool(True)

    #### Traits UI views ######################################################

    trait_view = View('prompt_on_exit')

#### EOF ######################################################################
